@@ -1,28 +1,13 @@
-/*
- * This file is part of gspell, a spell-checking library.
- *
- * Copyright 2002 - Paolo Maggi
- * Copyright 2015, 2016, 2017 - Sébastien Wilmet
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+/* SPDX-FileCopyrightText: 2002 - Paolo Maggi
+ * SPDX-FileCopyrightText: 2015, 2016, 2017 - Sébastien Wilmet
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 /* This is a modified version of GtkSpell 2.0.5 (gtkspell.sf.net)
- * Copyright 2002 - Evan Martin
+ * SPDX-FileCopyrightText: 2002 - Evan Martin
  */
 
-#include "config.h"
+#include "gspell-config.h"
 #include "gspell-inline-checker-text-buffer.h"
 #include <string.h>
 #include <glib/gi18n-lib.h>
